<?xml version="1.0"?>
<app>

<category>
Games
</category>

<name>
Simple Card Games
</name>

<description>
   <am>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</am>
   <ar>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</ar>
   <bg>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</bg>
   <ca>Jocs de cartes i trencaclosques senzills (solitari, cors, mines, etc.)</ca>
   <cs>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</cs>
   <da>Simple kortspil og puzzlespil til skrivebordet (7-kabale, hjerterfri, minestryger osv.)</da>
   <de>Einfache Desktop-Karten- und Puzzlespiele (Solitaire, Herzen, Minen, etc.)</de>
   <el>Παιχνίδια καρτών και παζλ (solitare, hearts, mines, etc)</el>
   <en>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</en>
   <es>Juegos de cartas y rompecabezas para sobremesa (solitario, corazones, minas, etc.)</es>
   <et>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</et>
   <eu>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</eu>
   <fa>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</fa>
   <fi>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</fi>
   <fr>Jeux de cartes et puzzles (solitaire, la dame de pique, mines, etc)</fr>
   <he_IL>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</he_IL>
   <hi>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</hi>
   <hr>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</hr>
   <hu>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</hu>
   <id>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</id>
   <is>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</is>
   <it>Semplici giochi di carte e puzzles (solitario, cuori, mine, ecc.)</it>
   <ja_JP>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</ja_JP>
   <ja>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</ja>
   <kk>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</kk>
   <ko>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</ko>
   <lt>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</lt>
   <mk>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</mk>
   <nb>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</nb>
   <nl>eenvoudige Desktop Kaart en Puzzel Spellen (solitaire, hearts, mines, etc)</nl>
   <pl>proste gry karciane i łamigłówki (solitare, hearts, mines itp.)</pl>
   <pt_BR>Jogos simples (solitare, hearts, mines, etc)</pt_BR>
   <pt>Jogos simples (solitare, hearts, mines, etc)</pt>
   <ro>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</ro>
   <ru>Простые карточные игры и головоломки (солитер, червы, сапёр, и т.д.)</ru>
   <sk>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</sk>
   <sl>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</sl>
   <sq>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</sq>
   <sr>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</sr>
   <sv>Enkla skrivbords kort och pusselspel (patiens, hjärter, minor, etc)</sv>
   <tr>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</tr>
   <uk>прості настільні карткові ігри та головоломки (solitare, hearts, mines та інші)</uk>
   <zh_CN>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</zh_CN>
   <zh_TW>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/screenshots/000/014/909/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
gnome-games
hearts
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
gnome-games
hearts
</uninstall_package_names>
</app>
